package cn.com.countrygarden.bi.main.dao.dup;

import java.util.List;

import javax.transaction.Transactional;

import org.springframework.stereotype.Repository;

import com.github.pagehelper.PageRowBounds;

import cn.com.countrygarden.bi.main.core.Mapper;
import cn.com.countrygarden.bi.main.model.dup.ContractStatistical;
import cn.com.countrygarden.bi.main.model.dup.ContractTimedExecute;

/**
 * 
 * 
 * <pre>
 * 。合同录入统计Mapper
 * </pre>
 * 
 * @author developer developer@meicloud.com
 * @version 1.00.00
 * 
 *          <pre>
 * 修改记录
 *    修改后版本:     修改人：  修改日期:     修改内容:
 * </pre>
 */
public interface ContractStatisticalMapper  extends Mapper<ContractStatistical>{
	
	/**
	 * 查询合同未录入统计数据(模糊查询)
	 * @return
	 */
	List<ContractStatistical> contractStatisticalSelect(ContractStatistical contractStatistical,PageRowBounds pageRowBounds);
	
	/**
	 * 查询合同未录入统计数据(模糊查询)
	 * @return
	 */
	List<ContractStatistical> contractStatisticalSelect1(ContractStatistical contractStatistical);
	
	/**
	 * 查询所有未录入的BIP数据
	 */
	List<String> findBIPnumber(ContractStatistical contractStatistical);
	
	/**
	 * 查询合同录入的总数
	 */
	int contractStatisticalSelecttotal();
	
	/**
	 * 查询未录入
	 */
	int contractStatisticalSelectNoImport();

	/**
	 * 删除已录入的数据
	 * @param bipNumber
	 * @return
	 */
	boolean deleteBIP(String bipNumber);
	
	/**
	 * 插入数据
	 */
	int insertdto(ContractStatistical contractStatistical);
	
	/**
	 * 调度时间
	 * @return
	 */
	ContractTimedExecute findDateStart();
	
	/**
	 * 插入下一次调度时间
	 * @param contractTimedExecute
	 * @return
	 */
	int  insterContractTimedExecute(ContractTimedExecute contractTimedExecute);
}
